# PoEPricePredictor
A work in progress. Using poe.ninja data dumps a time series predictor will be modelled and used for forecasting future prices of Path of Exile currency and items.

How to:
  Download and extract: https://poe.ninja/data
  Ensure you have the installed dependencies.
  Open the .ipynb in Jupyter
